@@ -12,17 +12,20 @@
 ##############################################################################
 """ Handles reading the properties for an object that comes from the filesystem.
 
-$Id: FSMetadata.py 40136 2005-11-15 17:41:36Z jens $
+$Id: FSMetadata.py 68524 2006-06-08 16:54:49Z efge $
 """
 
-from zLOG import LOG, ERROR
-from sys import exc_info
+import logging
 from os.path import exists
 from ConfigParser import ConfigParser
 from warnings import warn
 
 import re
 
+
+logger = logging.getLogger('CMFCore.FSMetadata')
+
+
 class CMFConfigParser(ConfigParser):
     """ This our wrapper around ConfigParser to
     solve a few minor niggles with the code """
@@ -90,10 +93,7 @@ class FSMetadata:
             self._security = self._getSectionDict(cfg, 'security',
                                                   self._securityParser)
         except:
-            LOG('FSMetadata',
-                 ERROR,
-                'Error parsing .metadata file',
-                 error=exc_info())
+            logger.exception("Error parsing .metadata file")
 
         # to add in a new value such as proxy roles,
         # just add in the section, call it using getSectionDict
@@ -169,10 +169,7 @@ class FSMetadata:
                 if len(kv) == 2:
                     props[kv[0].strip()] = kv[1].strip()
                 else:
-                    LOG('FSMetadata',
-                        ERROR,
-                        'Error parsing .properties file',
-                        error=exc_info())
+                    logger.exception("Error parsing .properties file")
 
             return props
 
@@ -207,10 +204,7 @@ class FSMetadata:
                         if role:
                             roles.append(role)
                 except:
-                    LOG('DirectoryView',
-                        ERROR,
-                        'Error reading permission from .security file',
-                        error=exc_info())
-                        # warning use of exc_info is deprecated
+                    logger.exception("Error reading permission "
+                                     "from .security file")
                 prm[permission]=(acquire,roles)
             return prm
