@@ -12,7 +12,7 @@
 ##############################################################################
 """DCWorkflow export / import support.
 
-$Id: exportimport.py 41472 2006-01-27 23:49:10Z jens $
+$Id: exportimport.py 68102 2006-05-12 06:05:10Z rafrombrc $
 """
 
 import re
@@ -31,7 +31,7 @@ from interfaces import IDCWorkflowDefinition
 from permissions import ManagePortal
 
 
-TRIGGER_TYPES = ( 'AUTOMATIC', 'USER' )
+TRIGGER_TYPES = ( 'AUTOMATIC', 'USER', 'WORKFLOWMETHOD' )
 _FILENAME = 'workflows.xml'
 
 
@@ -444,7 +444,6 @@ class WorkflowDefinitionConfigurator( Implicit ):
         items.sort()
 
         for k, v in items:
-
             guard = v.getGuard()
 
             v_info = []
@@ -470,7 +469,6 @@ class WorkflowDefinitionConfigurator( Implicit ):
                    }
 
             result.append( info )
-
         return result
 
     security.declarePrivate( '_extractWorklists' )
