@@ -12,13 +12,11 @@
 ##############################################################################
 """Filesystem exporter / importer adapter unit tests.
 
-$Id: test_content.py 40234 2005-11-18 21:22:13Z tseaver $
+$Id: test_content.py 68488 2006-06-04 17:22:57Z yuppie $
 """
 
 import unittest
 import Testing
-import Zope2
-Zope2.startup()
 
 from csv import reader
 from ConfigParser import ConfigParser
