@@ -12,7 +12,7 @@
 ##############################################################################
 """ Classes:  SetupTool
 
-$Id: tool.py 41383 2006-01-20 13:49:16Z efge $
+$Id: tool.py 68512 2006-06-07 16:24:12Z yuppie $
 """
 
 import os
@@ -96,12 +96,15 @@ def importToolset(context):
         tool_class = _resolveDottedName(info['class'])
 
         existing = getattr(aq_base(site), tool_id, None)
-        new_tool = tool_class()
-
         try:
-            new_tool._setId(tool_id)
-        except: # XXX:  ImmutableId raises result of calling MessageDialog
-            pass
+            new_tool = tool_class()
+        except TypeError:
+            new_tool = tool_class(tool_id)
+        else:
+            try:
+                new_tool._setId(tool_id)
+            except: # XXX:  ImmutableId raises result of calling MessageDialog
+                pass
 
         if existing is None:
             site._setObject(tool_id, new_tool)
@@ -186,7 +189,7 @@ class SetupTool(Folder):
         """
         return self._import_registry
 
-    security.declareProtected(ManagePortal, 'getImportStepRegistry')
+    security.declareProtected(ManagePortal, 'getExportStepRegistry')
     def getExportStepRegistry(self):
 
         """ See ISetupTool.
@@ -599,10 +602,16 @@ class SetupTool(Folder):
         """ Return the absolute path of the product's directory.
         """
         try:
+            # BBB: for GenericSetup 1.1 style product names
             product = __import__('Products.%s' % product_name
                                 , globals(), {}, ['initialize'])
         except ImportError:
-            raise ValueError, 'Not a valid product name: %s' % product_name
+            try:
+                product = __import__(product_name
+                                    , globals(), {}, ['initialize'])
+            except ImportError:
+                raise ValueError('Not a valid product name: %s'
+                                 % product_name)
 
         return product.__path__[0]
 
