@@ -12,7 +12,7 @@
 ##############################################################################
 """ GenericSetup product utilities
 
-$Id: utils.py 41640 2006-02-17 17:23:12Z yuppie $
+$Id: utils.py 67832 2006-05-02 12:51:17Z regebro $
 """
 
 import os
@@ -37,7 +37,7 @@ except:
     #BBB: for Zope 2.8
     from Products.Five.bbb.OFS_interfaces import IOrderedContainer
 from cgi import escape
-from zope.app import zapi
+from zope.component import queryMultiAdapter
 from zope.interface import implements
 from zope.interface import implementsOnly
 from zope.interface import providedBy
@@ -53,7 +53,9 @@ _pkgdir = package_home( globals() )
 _wwwdir = os.path.join( _pkgdir, 'www' )
 _xmldir = os.path.join( _pkgdir, 'xml' )
 
-CONVERTER, DEFAULT, KEY = range(3)
+# Please note that these values may change. Always import 
+# the values from here instead of using the values directly.
+CONVERTER, DEFAULT, KEY = 1, 2, 3
 I18NURI = 'http://xml.zope.org/namespaces/i18n'
 
 
@@ -531,7 +533,7 @@ class ObjectManagerHelpers(object):
             objects = list(objects)
             objects.sort(lambda x,y: cmp(x.getId(), y.getId()))
         for obj in objects:
-            exporter = zapi.queryMultiAdapter((obj, self.environ), INode)
+            exporter = queryMultiAdapter((obj, self.environ), INode)
             if exporter:
                 fragment.appendChild(exporter.node)
         return fragment
@@ -589,7 +591,7 @@ class ObjectManagerHelpers(object):
                         pass
 
             obj = getattr(self.context, obj_id)
-            importer = zapi.queryMultiAdapter((obj, self.environ), INode)
+            importer = queryMultiAdapter((obj, self.environ), INode)
             if importer:
                 importer.node = child
 
@@ -711,7 +713,7 @@ class PropertyManagerHelpers(object):
 def exportObjects(obj, parent_path, context):
     """ Export subobjects recursively.
     """
-    exporter = zapi.queryMultiAdapter((obj, context), IBody)
+    exporter = queryMultiAdapter((obj, context), IBody)
     path = '%s%s' % (parent_path, obj.getId().replace(' ', '_'))
     if exporter:
         if exporter.name:
@@ -728,7 +730,7 @@ def exportObjects(obj, parent_path, context):
 def importObjects(obj, parent_path, context):
     """ Import subobjects recursively.
     """
-    importer = zapi.queryMultiAdapter((obj, context), IBody)
+    importer = queryMultiAdapter((obj, context), IBody)
     path = '%s%s' % (parent_path, obj.getId().replace(' ', '_'))
     __traceback_info__ = path
     if importer:
